@@ -4,10 +4,10 @@ import click
 import logging
 from deployv_addon_gitlab_tools.commands import (
     check_keys, test_images, upload_image, deployv_tests, push_coverage,
-    build_image, test_image, check_log
+    build_image, test_image, check_log, test_repo
 )
 
-__version__ = "0.2.38"
+__version__ = "0.2.40"
 _logger = logging.getLogger('deployv.' + __name__)
 
 
@@ -35,8 +35,8 @@ for command in [
         push_coverage.push_coverage,
         build_image.build_image,
         test_image.test_image,
-        check_log.check_log
-
+        check_log.check_log,
+        test_repo.test_repo,
 ]:
     gitlab_tools.add_command(command)
 
